'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.moleculeThumbnailShape = exports.moleculeThumbnailRatio = exports.moleculeThumbnailSize = undefined;

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _values = require('babel-runtime/core-js/object/values');

var _values2 = _interopRequireDefault(_values);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _suiImagePlaceholder = require('@schibstedspain/sui-image-placeholder');

var _suiImagePlaceholder2 = _interopRequireDefault(_suiImagePlaceholder);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var BASE_CLASS = 'sui-MoleculeThumbnail';
var CAPTION_CLASS = BASE_CLASS + '-caption';
var LINK_CLASS = BASE_CLASS + '-link';

var SIZES = {
  LARGE: 'large',
  MEDIUM: 'medium',
  SMALL: 'small',
  XSMALL: 'xsmall'
};

var RATIOS = {
  '1:1': '1-1',
  '4:3': '4-3',
  '16:9': '16-9'
};

var SHAPES = {
  SQUARED: 'squared',
  CIRCLED: 'circled'
};

var MoleculeThumbnail = function MoleculeThumbnail(props) {
  var href = props.href,
      size = props.size,
      ratio = props.ratio,
      shape = props.shape,
      target = props.target,
      captionText = props.captionText,
      Link = props.linkFactory,
      alt = props.alt,
      src = props.src,
      placeholder = props.placeholder,
      fallback = props.fallback;


  var figure = _react2.default.createElement(
    'figure',
    {
      className: (0, _classnames2.default)('' + BASE_CLASS, BASE_CLASS + '--' + size, BASE_CLASS + '--' + ratio, BASE_CLASS + '--' + shape)
    },
    _react2.default.createElement(_suiImagePlaceholder2.default, {
      src: src,
      alt: alt,
      placeholder: placeholder,
      fallback: fallback
    }),
    captionText && _react2.default.createElement(
      'figcaption',
      { className: CAPTION_CLASS },
      captionText
    )
  );
  return href ? _react2.default.createElement(
    Link,
    {
      className: LINK_CLASS,
      href: href,
      target: target,
      rel: target === '_blank' && 'noopener'
    },
    figure
  ) : figure;
};

MoleculeThumbnail.displayName = 'MoleculeThumbnail';

MoleculeThumbnail.propTypes = process.env.NODE_ENV !== "production" ? process.env.NODE_ENV !== "production" ? {
  /**
   * Image source
   */
  src: _propTypes2.default.string.isRequired,
  /**
   * Image alt
   */
  alt: _propTypes2.default.string.isRequired,
  /**
   * Text shown at the bottom of the component
   */
  captionText: _propTypes2.default.string,
  /**
   * Img props to be shown until the image loads
   */
  placeholder: _propTypes2.default.object.isRequired,
  /**
   * Img props to be shown if the image fails loading
   */
  fallback: _propTypes2.default.object,
  /**
   * Anchor link
   */
  href: _propTypes2.default.string,
  /**
   * Define the target attribute('_self', '_blank', '_parent' or '_top')
   */
  target: _propTypes2.default.oneOf(['_self', '_blank', '_parent', '_top']),
  /**
   * Define the size (LARGE, MEDIUM, SMALL or XSMALL)
   */
  size: _propTypes2.default.oneOf((0, _values2.default)(SIZES)),
  /**
   * Define the shape (SQUARED or CIRCLED)
   */
  shape: _propTypes2.default.oneOf((0, _values2.default)(SHAPES)),
  /**
   * Define the ratio ('1:1', '4:3', '16:9')
   */
  ratio: _propTypes2.default.oneOf((0, _values2.default)(RATIOS)),
  /**
   * Factory used to create navigation links
   */
  linkFactory: _propTypes2.default.func
} : {} : {};

MoleculeThumbnail.defaultProps = {
  target: '_blank',
  size: SIZES.MEDIUM,
  shape: SHAPES.SQUARED,
  ratio: RATIOS['1:1'],
  linkFactory: function linkFactory() {
    var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var children = _ref.children,
        rest = (0, _objectWithoutProperties3.default)(_ref, ['children']);
    return _react2.default.createElement(
      'a',
      rest,
      children
    );
  }
};

exports.default = MoleculeThumbnail;
exports.moleculeThumbnailSize = SIZES;
exports.moleculeThumbnailRatio = RATIOS;
exports.moleculeThumbnailShape = SHAPES;